
# Description
This is a high-level async Python SDK for BSH Home Connect API. The API allows monitoring and controlling home appliances manufactured by BSH under brnad names such as Bosch, Siemens, Gaggenau and Neff.  

# Functionality
The SDK connects to the Home Connect API and retrieves all the data associated with the logged-in account, which is made available under the SDK's data model. Afterwards, the SDK maintains an up-to-date state by subscribing to receive real time updates from the API.

# Getting Access
This API provides access to home appliances enabled by Home Connect
(https://home-connect.com). Through the API programs can be started and
stopped, or home appliances configured and monitored. For instance, you can
start a cotton program on a washer and get a notification when the cycle is
complete.

To get started with this web client, visit https://developer.home-connect.com
and register an account. An application with a client ID for this API client
will be automatically generated for you.

# Legal Notice
This SDK is was not created by BSH and is not affiliated with it in any way.

# License
This SDK is licensed under the MIT license.
